@@ -3,7 +3,7 @@
 *                     A p p l i c a t i o n   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXApp.h,v 1.195.2.2 2005/03/18 05:36:12 fox Exp $                            *
+* $Id: FXApp.h,v 1.230 2006/01/22 17:57:58 fox Exp $                            *
 ********************************************************************************/
 #ifndef FXAPP_H
 #define FXAPP_H
@@ -32,6 +32,7 @@ namespace FX {
 
 
 // Forward declarations
+class FXApp;
 class FXWindow;
 class FXIcon;
 class FXBitmap;
@@ -45,7 +46,8 @@ class FXDCWindow;
 class FXVisual;
 class FXGLVisual;
 class FXGLContext;
-
+class FXTranslator;
+class FXComposeContext;
 
 // Opaque FOX objects
 struct FXTimer;
@@ -101,7 +103,8 @@ enum FXDefaultCursor {
   DEF_CORNERSW_CURSOR,                  /// South-west cursor
   DEF_HELP_CURSOR,                      /// Help arrow cursor
   DEF_HAND_CURSOR,                      /// Hand cursor
-  DEF_ROTATE_CURSOR                     /// Rotate cursor
+  DEF_ROTATE_CURSOR,                    /// Rotate cursor
+  DEF_WAIT_CURSOR                       /// Wait cursor
   };
 
 
@@ -114,7 +117,7 @@ struct FXAPI FXEvent {
   FXint       win_y;          /// Window-relative y-coord
   FXint       root_x;         /// Root x-coord
   FXint       root_y;         /// Root y-coord
-  FXint       state;          /// Keyboard/Modifier state
+  FXint       state;          /// Mouse button and modifier key state
   FXint       code;           /// Button, Keysym, or mode; DDE Source
   FXString    text;           /// Text of keyboard event
   FXint       last_x;         /// Window-relative x-coord of previous mouse location
@@ -156,7 +159,9 @@ class FXAPI FXApp : public FXObject {
   friend class FXGLContext;
   friend class FXDC;
   friend class FXDCWindow;
+  friend class FXDragCorner;
   friend class FXDockHandler;
+  friend class FXComposeContext;
 
 private:
 
@@ -165,7 +170,7 @@ private:
   const FXchar    *dpy;                 // Initial display guess
   FXHash           hash;                // Window handle hash table
   FXRegistry       registry;            // Application setting registry
-  FXWindow        *focusWindow;         // Window which has the focus
+  FXWindow        *activeWindow;        // Active toplevel window
   FXWindow        *cursorWindow;        // Window under the cursor
   FXWindow        *mouseGrabWindow;     // Window which grabbed the mouse
   FXWindow        *keyboardGrabWindow;  // Window which grabbed the keyboard
@@ -193,6 +198,7 @@ private:
   FXFont          *stockFont;           // Stock font
   FXMutex          appMutex;            // Application wide mutex
   FXEvent          event;               // Event
+  FXuint           stickyMods;          // Sticky modifier state
   FXInput         *inputs;              // Input file descriptors being watched
   FXint            ninputs;             // Number of inputs
   FXint            maxinput;            // Maximum input number
@@ -210,6 +216,7 @@ private:
   FXuint           tooltipTime;         // Tooltip display time
   FXint            dragDelta;           // Minimum distance considered a move
   FXint            wheelLines;          // Scroll by this many lines
+  FXint            scrollBarSize;       // Scrollbar size
   FXColor          borderColor;         // Border color
   FXColor          baseColor;           // Background color of GUI controls
   FXColor          hiliteColor;         // Highlight color of GUI controls
@@ -224,10 +231,14 @@ private:
   FXColor          selMenuBackColor;    // Select background color in menus
   FXCursor        *waitCursor;          // Current wait cursor
   FXuint           waitCount;           // Number of times wait cursor was called
-  FXCursor        *cursor[DEF_ROTATE_CURSOR+1];
+  FXuint           windowCount;         // Number of windows
+  FXCursor        *cursor[DEF_WAIT_CURSOR+1];
+  FXTranslator    *translator;          // Message translator
   FXint                appArgc;         // Argument count
   const FXchar *const *appArgv;         // Argument vector
-  FXbool           initialized;         // Has been initialized
+  const FXchar    *inputmethod;         // Input method name
+  const FXchar    *inputstyle;          // Input method style
+  bool             initialized;         // Has been initialized
 
 private:
   static FXApp    *app;                 // Application pointer
@@ -241,10 +252,20 @@ private:
   FXID             wmMotifHints;        // Motif hints
   FXID             wmTakeFocus;         // Focus explicitly set by app
   FXID             wmState;             // Window state
-  FXID             wmNetSupported;      // Extended Window Manager states list
   FXID             wmNetState;          // Extended Window Manager window state
+  FXID             wmNetIconName;       // Extended Window Manager icon name
+  FXID             wmNetWindowName;     // Extended Window Manager window name
+  FXID             wmNetSupported;      // Extended Window Manager states list
+  FXID             wmNetWindowType;     // Extended Window Manager types
   FXID             wmNetHMaximized;     // Extended Window Manager horizontally maximized
   FXID             wmNetVMaximized;     // Extended Window Manager vertically maximized
+  FXID             wmNetMoveResize;     // Extended Window Manager drag corner
+  FXID             wmNetPing;           // Extended Window Manager ping
+  FXID             wmNetTypes[8];       // Extended Window Manager window types
+  FXID             wmNetStates[12];     // Extended Window Manager state
+  FXID             wmWindowRole;        // Window Role
+  FXID             wmClientLeader;      // Client leader
+  FXID             wmClientId;          // Client id
   FXID             embedAtom;           // XEMBED support
   FXID             embedInfoAtom;       // XEMBED info support
   FXID             timestampAtom;       // Server time
@@ -283,6 +304,7 @@ private:
   FXbool           xdndStatusPending;   // XDND waiting for status feedback
   FXbool           xdndStatusReceived;  // XDND received at least one status
   FXbool           xdndWantUpdates;     // XDND target wants new positions while in rect
+  FXbool           xdndFinishSent;      // XDND finish sent
   FXRectangle      xdndRect;            // XDND rectangle bounding target
   FXint            xrreventbase;        // XRR event base
   FXID             stipples[23];        // Standard stipple patterns
@@ -290,7 +312,6 @@ private:
   void            *w_fds;               // Set of file descriptors for write
   void            *e_fds;               // Set of file descriptors for exceptions
   void            *xim;                 // Input method
-  void            *xic;                 // Input method context
   FXbool           shmi;                // Use XSHM Image possible
   FXbool           shmp;                // Use XSHM Pixmap possible
   FXbool           synchronize;         // Synchronized
@@ -313,6 +334,7 @@ private:
   FXbool           xdndStatusPending;   // XDND waiting for status feedback
   FXbool           xdndFinishPending;   // XDND waiting for drop-confirmation
   FXbool           xdndStatusReceived;  // XDND received at least one status
+  FXbool           xdndFinishSent;      // XDND finish sent
   FXRectangle      xdndRect;            // XDND rectangle bounding target
   FXID             stipples[17];        // Standard stipple bitmaps
   void           **handles;             // Waitable object handles
@@ -341,19 +363,21 @@ private:
   void addRepaint(FXID win,FXint x,FXint y,FXint w,FXint h,FXbool synth=0);
   void removeRepaints(FXID win,FXint x,FXint y,FXint w,FXint h);
   void scrollRepaints(FXID win,FXint dx,FXint dy);
+  static void imcreatecallback(void*,FXApp*,void*);
+  static void imdestroycallback(void*,FXApp*,void*);
 #else
-  static long CALLBACK wndproc(FXID hwnd,unsigned int iMsg,unsigned int wParam,long lParam);
+  static FXival CALLBACK wndproc(FXID hwnd,FXuint iMsg,FXuval wParam,FXival lParam); 
 protected:
-  virtual long dispatchEvent(FXID hwnd,unsigned int iMsg,unsigned int wParam,long lParam);
+  virtual FXival dispatchEvent(FXID hwnd,FXuint iMsg,FXuval wParam,FXival lParam);
 #endif
 
 protected:
 
   /// Return TRUE when new raw event is available
-  virtual FXbool getNextEvent(FXRawEvent& ev,FXbool blocking=TRUE);
+  virtual bool getNextEvent(FXRawEvent& ev,bool blocking=true);
 
   /// Dispatch raw event
-  virtual FXbool dispatchEvent(FXRawEvent& ev);
+  virtual bool dispatchEvent(FXRawEvent& ev);
 
 public:
   long onCmdQuit(FXObject*,FXSelector,void*);
@@ -391,16 +415,16 @@ public:
   const FXString& getVendorName() const { return registry.getVendorKey(); }
 
   /// Connection to display; this is called by init()
-  FXbool openDisplay(const FXchar* dpyname=NULL);
+  bool openDisplay(const FXchar* dpyname=NULL);
 
   /// Close connection to the display
-  FXbool closeDisplay();
+  bool closeDisplay();
 
   /// Return pointer
   void* getDisplay() const { return display; }
 
   /// Is application initialized
-  FXbool isInitialized() const { return initialized; }
+  bool isInitialized() const { return initialized; }
 
   /// Get argument count
   FXint getArgc() const { return appArgc; }
@@ -408,6 +432,9 @@ public:
   /// Get argument vector
   const FXchar *const *getArgv() const { return appArgv; }
 
+  /// Return true if input method support
+  bool hasInputMethod() const;
+
   /// Get default visual
   FXVisual* getDefaultVisual() const { return defaultVisual; }
 
@@ -423,11 +450,14 @@ public:
   /// Set root Window
   void setRootWindow(FXRootWindow* rt);
 
+  /// Return window at the end of the focus chain
+  FXWindow *getFocusWindow() const;
+
   /// Get the window under the cursor, if any
   FXWindow *getCursorWindow() const { return cursorWindow; }
 
-  /// Get the window which has the focus, if any
-  FXWindow *getFocusWindow() const { return focusWindow; }
+  /// Get the active toplevel window, if any
+  FXWindow *getActiveWindow() const { return activeWindow; }
 
   /// Get current popup window, if any
   FXPopup* getPopupWindow() const { return popupWindow; }
@@ -464,7 +494,7 @@ public:
   /**
   * Return TRUE if given timeout has been set
   */
-  FXbool hasTimeout(FXObject *tgt,FXSelector sel) const;
+  bool hasTimeout(FXObject *tgt,FXSelector sel) const;
 
   /**
   * Return, in ms, the time remaining until the given timer fires.
@@ -495,7 +525,7 @@ public:
   /**
   * Return TRUE if given chore has been set
   */
-  FXbool hasChore(FXObject *tgt,FXSelector sel) const;
+  bool hasChore(FXObject *tgt,FXSelector sel) const;
 
   /**
   * Add signal processing message to be sent to target object when
@@ -515,22 +545,22 @@ public:
   * A message of type SEL_IO_READ, SEL_IO_WRITE, or SEL_IO_EXCEPT will be sent
   * to the target when the specified activity is detected on the file descriptor.
   */
-  FXbool addInput(FXInputHandle fd,FXuint mode,FXObject *tgt,FXSelector sel);
+  bool addInput(FXInputHandle fd,FXuint mode,FXObject *tgt,FXSelector sel);
 
   /**
   * Remove input message and target object for the specified file descriptor
   * and mode, which is a bitwise OR of (INPUT_READ, INPUT_WRITE, INPUT_EXCEPT).
   */
-  FXbool removeInput(FXInputHandle fd,FXuint mode);
+  bool removeInput(FXInputHandle fd,FXuint mode);
 
-  /// Return key state
-  FXbool getKeyState(FXuint keysym) const;
+  /// Return key state of given key
+  bool getKeyState(FXuint keysym) const;
 
   /// Peek to determine if there's an event
-  FXbool peekEvent();
+  bool peekEvent();
 
   /// Perform one event dispatch; return true if event was dispatched
-  FXbool runOneEvent(FXbool blocking=TRUE);
+  bool runOneEvent(bool blocking=true);
 
   /**
   * Run the main application event loop until stop() is called,
@@ -586,7 +616,7 @@ public:
   FXint runPopup(FXWindow* window);
 
   /// True if the window is modal
-  FXbool isModal(FXWindow* window) const;
+  bool isModal(FXWindow* window) const;
 
   /// Return window of current modal loop
   FXWindow* getModalWindow() const;
@@ -619,7 +649,7 @@ public:
   void refresh();
 
   /// Flush pending repaints
-  void flush(FXbool sync=FALSE);
+  void flush(bool sync=false);
 
   /**
   * Paint all windows marked for repainting.
@@ -632,7 +662,7 @@ public:
   * Parses and removes common command line arguments, reads the registry.
   * Finally, if connect is TRUE, it opens the display.
   */
-  virtual void init(int& argc,char** argv,FXbool connect=TRUE);
+  virtual void init(int& argc,char** argv,bool connect=true);
 
   /**
   * Exit application.
@@ -687,6 +717,18 @@ public:
   /// Change default cursor
   void setDefaultCursor(FXDefaultCursor which,FXCursor* cur);
 
+  /**
+  * Write a window and its children, and all resources reachable from this
+  * window, into the stream store. (EXPERIMENTAL!)
+  */
+  FXbool writeWindow(FXStream& store,FXWindow *window);
+
+  /**
+  * Read a window and its children from the stream store, and append
+  * it under father; note it is initially not created yet. (EXPERIMENTAL!)
+  */
+  FXbool readWindow(FXStream& store,FXWindow*& window,FXWindow* father,FXWindow* owner);
+
   /**
   * Return a reference to the application-wide mutex.
   * Normally, the main user interface thread holds this mutex,
@@ -701,6 +743,15 @@ public:
   */
   FXMutex& mutex(){ return appMutex; }
 
+  /**
+  * Change message translator.
+  * The new translator will be owned by FXApp.
+  */
+  void setTranslator(FXTranslator* trans);
+
+  /// Return message translator
+  FXTranslator* getTranslator() const { return translator; }
+
   /// Obtain application-wide settings
   FXuint getTypingSpeed() const { return typingSpeed; }
   FXuint getClickSpeed() const { return clickSpeed; }
@@ -713,6 +764,7 @@ public:
   FXuint getTooltipTime() const { return tooltipTime; }
   FXint getDragDelta() const { return dragDelta; }
   FXint getWheelLines() const { return wheelLines; }
+  FXint getScrollBarSize() const { return scrollBarSize; }
 
   /// Change application-wide settings
   void setTypingSpeed(FXuint speed);
@@ -726,6 +778,7 @@ public:
   void setTooltipTime(FXuint time);
   void setDragDelta(FXint delta);
   void setWheelLines(FXint lines);
+  void setScrollBarSize(FXint size);
 
   /// Obtain default colors
   FXColor getBorderColor() const { return borderColor; }
@@ -755,6 +808,9 @@ public:
   void setSelMenuTextColor(FXColor color);
   void setSelMenuBackColor(FXColor color);
 
+  /// Get number of existing windows
+  FXuint getWindowCount() const { return windowCount; }
+
   /// Save
   virtual void save(FXStream& store) const;
 
