@@ -3,7 +3,7 @@
 *                        C U R   C u r s o r    O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2005 by Sander Jansen.   All Rights Reserved.              *
+* Copyright (C) 2001,2006 by Sander Jansen.   All Rights Reserved.              *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCURCursor.h,v 1.16 2005/01/16 16:06:06 fox Exp $                       *
+* $Id: FXCURCursor.h,v 1.18 2006/01/22 17:57:59 fox Exp $                       *
 ********************************************************************************/
 #ifndef FXCURCURSOR_H
 #define FXCURCURSOR_H
@@ -49,10 +49,10 @@ public:
   FXCURCursor(FXApp* a,const void* pix);
 
   /// Save pixel data only, in CUR format
-  virtual FXbool savePixels(FXStream& store) const;
+  virtual bool savePixels(FXStream& store) const;
 
   /// Load pixel data only, in CUR format
-  virtual FXbool loadPixels(FXStream& store);
+  virtual bool loadPixels(FXStream& store);
 
   /// Destructor
   virtual ~FXCURCursor();
@@ -65,7 +65,7 @@ public:
 /**
 * Check if stream contains a ICO, return TRUE if so.
 */
-extern FXAPI FXbool fxcheckICO(FXStream& store);
+extern FXAPI bool fxcheckICO(FXStream& store);
 
 
 /**
@@ -73,14 +73,14 @@ extern FXAPI FXbool fxcheckICO(FXStream& store);
 * Upon successful return, the pixel array and size are returned.
 * If an error occurred, the pixel array is set to NULL.
 */
-extern FXAPI FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot);
+extern FXAPI bool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot);
 
 
 /**
 * Save an ICO (Microsoft icon format) file to a stream.
 * If no hot-spot given, save as an ICO instead of a CUR resource.
 */
-extern FXAPI FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot=-1,FXint yspot=-1);
+extern FXAPI bool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot=-1,FXint yspot=-1);
 
 #endif
 
