@@ -3,7 +3,7 @@
 *                            L i s t   W i d g e t                              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXList.h,v 1.82.2.1 2005/04/10 03:24:47 fox Exp $                            *
+* $Id: FXList.h,v 1.88.2.2 2006/11/17 16:02:31 fox Exp $                            *
 ********************************************************************************/
 #ifndef FXLIST_H
 #define FXLIST_H
@@ -57,6 +57,9 @@ protected:
   void     *data;
   FXuint    state;
   FXint     x,y;
+private:
+  FXListItem(const FXListItem&);
+  FXListItem& operator=(const FXListItem&);
 protected:
   FXListItem():icon(NULL),data(NULL),state(0),x(0),y(0){}
   virtual void draw(const FXList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h);
@@ -146,6 +149,7 @@ public:
 typedef FXint (*FXListSortFunc)(const FXListItem*,const FXListItem*);
 
 
+/// List of FXListItem's
 typedef FXObjectListOf<FXListItem> FXListItemList;
 
 
@@ -170,6 +174,7 @@ protected:
   FXint          current;           // Current item
   FXint          extent;            // Extent item
   FXint          cursor;            // Cursor item
+  FXint          viewable;          // Viewable item
   FXFont        *font;              // Font
   FXColor        textColor;         // Text color
   FXColor        selbackColor;      // Selected back color
@@ -256,7 +261,7 @@ public:
   virtual void recalc();
 
   /// List widget can receive focus
-  virtual FXbool canFocus() const;
+  virtual bool canFocus() const;
 
   /// Move the focus to this window
   virtual void setFocus();
@@ -309,6 +314,9 @@ public:
   /// Move item from oldindex to newindex
   FXint moveItem(FXint newindex,FXint oldindex,FXbool notify=FALSE);
 
+  /// Extract item from list
+  FXListItem* extractItem(FXint index,FXbool notify=FALSE);
+
   /// Remove item from list
   void removeItem(FXint index,FXbool notify=FALSE);
 
