@@ -3,7 +3,7 @@
 *                   M a i n   F O X   I n c l u d e   F i l e                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fx.h,v 1.90.2.1 2005/02/16 05:40:09 fox Exp $                                *
+* $Id: fx.h,v 1.104 2006/01/22 17:58:13 fox Exp $                               *
 ********************************************************************************/
 #ifndef FX_H
 #define FX_H
@@ -34,12 +34,18 @@
 // FOX defines
 #include "fxver.h"
 #include "fxdefs.h"
+#include "fxascii.h"
+#include "fxunicode.h"
 
 // FOX classes
 #include "FXHash.h"
 #include "FXException.h"
 #include "FXThread.h"
 #include "FXStream.h"
+#include "FXIO.h"
+#include "FXFile.h"
+#include "FXPipe.h"
+#include "FXSocket.h"
 #include "FXFileStream.h"
 #include "FXMemoryStream.h"
 #include "FXString.h"
@@ -49,7 +55,11 @@
 #include "FXObject.h"
 #include "FXDelegator.h"
 #include "FXDict.h"
-#include "FXFile.h"
+#include "FXPath.h"
+#include "FXSystem.h"
+#include "FXStat.h"
+#include "FXDir.h"
+#include "FXDate.h"
 #include "FXURL.h"
 #include "FXStringDict.h"
 #include "FXSettings.h"
@@ -62,6 +72,7 @@
 #include "FXVisual.h"
 #include "FXFont.h"
 #include "FXCursor.h"
+#include "FXGUISignal.h"
 #include "FXCURCursor.h"
 #include "FXGIFCursor.h"
 #include "FXDrawable.h"
@@ -103,7 +114,9 @@
 #include "FXLabel.h"
 #include "FX7Segment.h"
 #include "FXDial.h"
+#include "FXKnob.h"
 #include "FXColorBar.h"
+#include "FXColorRing.h"
 #include "FXColorWell.h"
 #include "FXColorWheel.h"
 #include "FXTextField.h"
@@ -192,6 +205,7 @@
 #include "FXProgressBar.h"
 #include "FXReplaceDialog.h"
 #include "FXRuler.h"
+#include "FXRulerView.h"
 #include "FXSearchDialog.h"
 #include "FXInputDialog.h"
 #include "FXProgressDialog.h"
